"""
This program is a library to communicate with the Centreon REST API

Copyright (C) 2019 Niklas Pfister, contact@omikron.pw

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""


class Macro:
    """This class represents a macro

    :param macro_name: Name of the macro
    :type macro_name: str
    :param macro_value: Value of the macro
    :type macro_name: str
    :param is_password: Is the macro an password?
    :type is_password: bool
    :param description: Description of the macro
    :type description: str
    :param source: Source the macro came from
    :type source: str
    """
    def __init__(self, *, macro_name, macro_value, is_password, description, source):
        self.macro_name = macro_name
        self.macro_value = macro_value
        self.is_password = is_password
        self.description = description
        self.source = source



"""
This program is a library to communicate with the Centreon REST API

Copyright (C) 2019 Niklas Pfister, contact@omikron.pw

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""
import enum


class Service:
    """This class represents a service
    
    :param host_id: ID of the host
    :type host_id: int
    :param host_name: Name of the host
    :type host_name: str
    :param id_unique: ID of the service
    :type id_unique: int
    :param description: Description of the service
    :type description: str
    :param check_command: Check command
    :type check_command: str
    :param check_command_arg: Check command argument
    :type check_command_arg: list of str
    :param normal_check_interval: Normal check interval
    :type normal_check_interval: int
    :param retry_check_interval: Retry check interval
    :type retry_check_interval: int
    :param max_check_attempts: Maximum check attempts
    :type max_check_attempts: int
    :param active_checks_enabled: Are activate checks enabled?
    :type active_checks_enabled: int
    :param passive_checks_enabled: Are passive check enabled?
    :type passive_checks_enabled: int
    :param activate: Is the service enabled?
    :type activate: int
    """
    def __init__(self, host_id, host_name, id_unique, description, check_command, check_command_arg, 
                 normal_check_interval, retry_check_interval, max_check_attempts, active_checks_enabled,
                 passive_checks_enabled, activate):
        self.host_id = host_id
        self.host_name = host_name
        self.id_unique = id_unique
        self.description = description
        self.check_command = check_command 
        self.check_command_arg = check_command_arg
        self.normal_check_interval = normal_check_interval
        self.retry_check_interval = retry_check_interval
        self.max_check_attempts = max_check_attempts
        self.active_checks_enabled = active_checks_enabled
        self.passive_checks_enabled = passive_checks_enabled
        self.activate = activate


class ServiceParam(enum.Enum):
    """This class represents the parameters of a service"""
    ACTIVATE = "activate"
    """Enable or disable a service (bool)"""
    DESCRIPTION = "description"
    """Description of the service (str)"""
    TEMPLATE = "template"
    """Name of the service template (str)"""
    IS_VOLATILE = "is_volatile"
    """Set True when service is volatile (bool)"""
    CHECK_PERIOD = "check_period"
    """Name of the check period (str)"""
    CHECK_COMMAND = "check_command"
    """Name of the check command (str)"""
    CHECK_COMMAND_ARGUMENTS = "check_command_arguments"
    """Check command arguments (list of str)"""
    MAX_CHECK_ATTEMPTS = "max_check_attempts"
    """Maximum number of attempt before a HARD state is declared (int)"""
    NORMAL_CHECK_INTERVAL = "normal_check_interval"
    """Time between the checks should be executed, in minutes (int)"""
    RETRY_CHECK_INTERVAL = "retry_check_interval"
    """Time after the next check should be executed, if the one before failed, in minutes (int)"""
    ACTIVATE_CHECKS_ENABLED = "activate_checks_enabled"
    """Set True when active checks are enabled (bool)"""
    PASSIVE_CHECKS_ENABLED = "passive_checks_enabled"
    """Set True if passive checks are enabled (bool)"""
    NOTIFICATIONS_ENABLED = "notifications_enabled"
    """Set True if notification should be enabled (bool)"""
    CONTACT_ADDITIVE_INHERITANCE = "contact_additive_inheritance"
    """Set True if you want contact additive inheritance (bool)"""
    CONTACT_GROUP_ADDITIVE_INHERITANCE = "cg_additive_inheritance"
    """Set True if you want contact group additive inheritance (bool)"""
    NOTIFICATION_INTERVAL = "notification_interval"
    """Interval between the notifications should be sent, in minutes (int)"""
    NOTIFICATION_PERIOD = "notification_period"
    """Name of the notification period (str)"""
    NOTIFICATION_OPTIONS = "notification_options"
    """Status linked to the notifications (str)"""
    FIRST_NOTIFICATION_DELAY = "first_notification_delay"
    """Delay after which the first notification should be sent, in minutes (int)"""
    RECOVERY_NOTIFICATION_DELAY = "recovery_notification_delay"
    """Delay after which the first recovery notification should be sent, in minutes (int)"""
    OBSESS_OVER_SERVICE = "obsess_over_service"
    """Set True when obsess over service should be enabled (bool)"""
    CHECK_FRESHNESS = "check_freshness"
    """Set True if check freshness should be enabled (bool)"""
    FRESHNESS_THRESHOLD = "freshness_threshold"
    """Freshness threshold, in seconds (int)"""
    EVENT_HANDLER_ENABLED = "event_handler_enabled"
    """Set True if the event handler should be enabled (bool)"""
    FLAP_DETECTION_ENABLED = "flap_detection_enabled"
    """Set True if flap detection should be enabled (bool)"""
    RETAIN_STATUS_INFORMATION = "retain_status_information"
    """Set True when status information should be retained (bool)"""
    RETAIN_NONSTATUS_INFORMATION = "retain_nonstatus_information"
    """Set True when nonstatus information should bne retained (bool)"""
    EVENT_HANDLER = "event_handler"
    """Name of the event handler command (str)"""
    EVENT_HANDLER_ARGUMENTS = "event_handler_arguments"
    """List of the event handler arguments (list of str)"""
    NOTES = "notes"
    """Notes regarding the service (str)"""
    URL = "notes_url"
    """URL which is linked to the service (str)"""
    ACTION_URL = "action_url"
    """Action URL which is linked to the service (str)"""
    ICON_IMAGE = "icon_image"
    """Name of the icon which should be used (str)"""
    ICON_IMAGE_ALT = "icon_image_alt"
    """Alternative image (str)"""
    COMMENT = "comment"
    """Comment of the service (str)"""
    SERVICE_NOTIFICATION_OPTIONS = "service_notification_options"
    """Set the notification type (:ref:`class_service_notification_option`)"""


class ServiceNotificationOption(enum.Enum):
    """This class represents a service notification option

    :Note:
        Type None can only be selected separately
    """
    WARNING = "w",
    UNKNOWN = "u",
    CRITICAL = "c",
    RECOVERY = "r",
    FLAPPING = "f",
    DOWNTIME_SCHEDULED = "s",
    NONE = "n"



"""
This program is a library to communicate with the Centreon REST API

Copyright (C) 2019 Niklas Pfister, contact@omikron.pw

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""
import enum


class ContactTemplate:
    """This class represents a contact template

    :param name: Name of the contact
    :type name: str
    :param alias: Alias of the contact
    :type alias: str
    :param email: EMail of the contact
    :type email: str
    :param pager: Pager of the contact
    :type pager: str
    :param admin: Is the contact admin?
    :type admin: bool
    :param id_unique: ID of the contact
    :type id_unique: int
    :param gui_access: Has the contact access to the gui
    :type gui_access: bool
    :param activate: Is the template activated?
    :type activate: bool
    """
    def __init__(self, name, alias, email, pager, admin, id_unique, gui_access, activate):
        self.name = name
        self.alias = alias
        self.email = email
        self.pager = pager
        self.admin = admin
        self.id_unique = id_unique
        self.gui_access = gui_access
        self.activate = activate


class ContactTemplateAuthType(enum.Enum):
    """This class represents the available authentication types which can be used by an user"""
    LDAP = "ldap"
    LOCAL = "local"


class ContactTemplateParam(enum.Enum):
    """This class represents the available parameter you could change / set in a contact template"""
    NAME = "name"
    ALIAS = "alias"
    COMMENT = "comment"
    EMAIL = "email"
    PASSWORD = "password"
    ACCESS = "access"
    LANGUAGE = "language"
    ADMIN = "admin"
    AUTHTYPE = "authtype"
    HOSTNOTIFCMD = "hostnotifcmd"
    SVCNOTIFCMD = "svcnotifcmd"
    HOSTNOTIFPERIOD = "hostnotifperiod"
    SVCNOTIFPERIOD = "svcnotifperiod"
    HOSTNOTIFOPT = "hostnotifopt"
    SERVICENOTIFOPT = "servicenotifopt"
    ADDRESS1 = "address1"
    ADDRESS2 = "address2"
    ADDRESS3 = "address3"
    ADDRESS4 = "address4"
    ADDRESS5 = "address5"
    ADDRESS6 = "address6"
    LDAP_DN = "ldap_dn"
    ENABLE_NOTIFICATIONS = "enable_notifications"
    AUTOLOGIN_KEY = "autologin_key"
    TEMPLATE = "template"
    TIMEZONE = "timezone"



"""
This program is a library to communicate with the Centreon REST API

Copyright (C) 2019 Niklas Pfister, contact@omikron.pw

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""
import enum


class CentEngineCFG:
    """This class represents a centreon engine configuration

    :param id_unique: ID of the centreon engine
    :type id_unique: int
    :param name: Name of the centreon configuration
    :type name: str
    :param instance: Instance that is linked to centreon-engine.cfg
    :type instance: str
    :param comment: Comments regarding centreon configuration file
    :type comment: str
    """
    def __init__(self, id_unique, name, instance, comment):
        self.id_unique = id_unique
        self.name = name
        self.instance = instance
        self.comment = comment


class CentEngineCFGParam(enum.Enum):
    NAME = "nagios_name"
    COMMENT = "nagios_comment"
    ACTIVATE = "nagios_activate"
    LOG_FILE = "log_file"
    OBJECT_CONFIGURATION_DIR = "cfg_dir"
    STATUS_FILE = "status_file"
    TEMP_FILE = "temp_file"
    LOCK_FILE = "lock_file"
    OBJECT_CONFIGURATION_FILE = "cfg_file"
    ENABLE_NOTIFICATIONS = "enable_notifications"
    EXECUTE_SERVICE_CHECKS = "execute_service_checks"
    ACCEPT_PASSIVE_SERVICE_CHECKS = "accept_passive_service_checks"
    EXECUTE_HOST_CHECKS = "execute_host_checks"
    ACCEPT_PASSIVE_HOST_CHECKS = "accept_passive_host_checks"
    ENABLE_EVENT_HANDLERS = "enable_event_handlers"
    LOG_ARCHIVE_PATH = "log_archive_path"
    CHECK_EXTERNAL_COMMANDS = "check_external_commands"
    COMMAND_CHECK_INTERVAL = "command_check_interval"
    COMMAND_FILE = "command_file"
    RETAIN_STATE_INFORMATION = "retain_state_information"
    STATE_RETENTION_FILE = "state_retention_file"
    RETENTION_UPDATE_INTERVAL = "retention_update_interval"
    USE_RETAINED_PROGRAM_STATE = "use_retained_program_state"
    USE_RETAINED_SCHEDULING_INFO = "use_retained_scheduling_info"
    USE_SYSLOG = "use_syslog"
    LOG_NOTIFICATIONS = "log_notifications"
    LOG_SERVICE_RETRIES = "log_service_retries"
    LOG_HOST_RETRIES = "log_host_retries"
    LOG_EVENT_HANDLERS = "log_event_handlers"
    LOG_EXTERNAL_COMMANDS = "log_external_commands"
    LOG_PASSIVE_CHECKS = "log_passive_checks"
    SLEEP_TIME = "sleep_time"
    SERVICE_INTER_CHECK_DELAY_METHOD = "service_inter_check_delay_method"
    SERVICE_INTERLEAVE_FACTOR = "service_interleave_factor"
    MAX_CONCURRENT_CHECKS = "max_concurrent_checks"
    MAX_SERVICE_CHECK_SPREAD = "max_service_check_spread"
    CHECK_RESULT_REAPER_FREQUENCY = "check_result_reaper_frequency"
    INTERVAL_LENGTH = "interval_length"
    AUTO_RESCHEDULE_CHECKS = "auto_reschedule_checks"
    ENABLE_FLAP_DETECTION = "enable_flap_detection"
    LOW_SERVICE_FLAP_THRESHOLD = "low_service_flap_threshold"
    HIGH_SERVICE_FLAP_THRESHOLD = "high_service_flap_threshold"
    LOW_HOST_FLAP_THRESHOLD = "low_host_flap_threshold"
    HIGH_HOST_FLAP_THRESHOLD = "high_host_flap_threshold"
    SOFT_STATE_DEPENDENCIES = "soft_state_dependencies"
    SERVICE_CHECK_TIMEOUT = "service_check_timeout"
    HOST_CHECK_TIMEOUT = "host_check_timeout"
    EVENT_HANDLER_TIMEOUT = "event_handler_timeout"
    NOTIFICATION_TIMEOUT = "notification_timeout"
    OCSP_TIMEOUT = "ocsp_timeout"
    OCHP_TIMEOUT = "ochp_timeout"
    PERFDATA_TIMEOUT = "perfdata_timeout"
    OBSESS_OVER_SERVICES = "obsess_over_services"
    OBSESS_OVER_HOSTS = "obsess_over_hosts"
    PROCESS_PERFORMANCE_DATA = "process_performance_data"
    HOST_PERFDATA_FILE_MODE = "host_perfdata_file_mode"
    SERVICE_PERFDATA_FILE_MODE = "service_perfdata_file_mode"
    CHECK_FOR_ORPHANED_SERVICES = "check_for_orphaned_services"
    CHECK_FOR_ORPHANED_HOSTS = "check_for_orphaned_hosts"
    CHECK_SERVICE_FRESHNESS = "check_service_freshness"
    CHECK_HOST_FRESHNESS = "check_host_freshness"
    DATE_FORMAT = "date_format"
    ILLEGAL_OBJECT_NAME_CHARS = "illegal_object_name_chars"
    ILLEGAL_MACRO_OUTPUT_CHARS = "illegal_macro_output_chars"
    USE_REGEXP_MATCHING = "use_regexp_matching"
    USE_TRUE_REGEXP_MATCHING = "use_true_regexp_matching"
    ADMIN_EMAIL = "admin_email"
    ADMIN_PAGER = "admin_pager"
    NAGIOS_ACTIVATE = "nagios_activate"
    EVENT_BROKER_OPTIONS = "event_broker_options"
    ENABLE_PREDICTIVE_HOST_DEPENDENCY_CHECKS = "enable_predictive_host_dependency_checks"
    ENABLE_PREDICTIVE_SERVICE_DEPENDENCY_CHECKS = "enable_predictive_service_dependency_checks"
    USE_LARGE_INSTALLATION_TWEAKS = "use_large_installation_tweaks"
    ENABLE_ENVIRONMENT_MACROS = "enable_environment_macros"
    DEBUG_LEVEL = "debug_level"
    DEBUG_LEVEL_OPT = "debug_level_opt"
    DEBUG_VERBOSITY = "debug_verbosity"
    CACHED_HOST_CHECK_HORIZON = "cached_host_check_horizon"
    RETAINED_CONTACT_HOST_ATTRIBUTE_MASK = "retained_contact_host_attribute_mask"
    RETAINED_CONTACT_SERVICE_ATTRIBUTE_MASK = "retained_contact_service_attribute_mask"
    LOG_INITIAL_STATE = "log_initial_states"
    GLOBAL_HOST_EVENT_HANDLER = "global_host_event_handler"
    GLOBAL_SERVICE_EVENT_HANDLER = "global_service_event_handler"
    MAX_CHECK_RESULT_REAPER_TIME = "max_check_result_reaper_time"
    USE_CHECK_RESULT_PATH = "use_check_result_path"
    CHECK_RESULT_PATH = "check_result_path"
    MAX_CHECK_RESULT_FILE_AGE = "max_check_result_file_age"
    HOST_INTER_CHECK_DELAY_METHOD = "host_inter_check_delay_method"
    MAX_HOST_CHECK_SPREAD = "max_host_check_spread"
    AUTO_RESCHEDULING_INTERVAL = "auto_rescheduling_interval"
    AUTO_RESCHEDULE_WINDOW = "auto_rescheduling_window"
    USE_AGRESSIVE_HOST_CHECKING = "use_aggressive_host_checking"
    TRANSLATE_PASSIVE_HOST_CHECKS = "translate_passive_host_checks"
    PASSIVE_HOST_CHECKS_ARE_SOFT = "passive_host_checks_are_soft"
    CACHED_SERVICE_CHECK_HORIZON = "cached_service_check_horizon"
    USE_SETGPIG = "use_setpgid"
    OSCP_COMMAND = "ocsp_command"
    OCHP_COMMAND = "ochp_command"
    HOST_PERFDATA_COMMAND = "host_perfdata_command"
    SERVICE_PERFDATA_COMMAND = "service_perfdata_command"
    HOST_PERFDATA_FILE = "host_perfdata_file"
    SERVICE_PERFDATA_FILE = "service_perfdata_file"
    HOST_PERFDATA_FILE_TEMPLATE = "host_perfdata_file_template"
    SERVICE_PERFDATA_FILE_TEMPLATE = "service_perfdata_file_template"
    HOST_PERFDATA_FILE_PROCESSING_INTERVAL = "host_perfdata_file_processing_interval"
    SERVICE_PERFDATA_FILE_PROCESSING_INTERVAL = "service_perfdata_file_processing_interval"
    HOST_PERFDATA_FILE_PROCESSING_COMMAND = "host_perfdata_file_processing_command"
    SERVICE_PERFDATA_FILE_PROCESSING_COMMAND = "service_perfdata_file_processing_command"
    SERVICE_FRESHNESS_CHECK_INTERVAL = "service_freshness_check_interval"
    HOST_FRESHNESS_CHECK_INTERVAL = "host_freshness_check_interval"
    ADDITIONAL_FRESHNESS_LATENCY = "additional_freshness_latency"
    USE_TIMEZONE = "use_timezone"
    BROKER_MODULE = "broker_module"
    DEBUG_FILE = "debug_file"
    MAX_DEBUG_FILE_SIZE = "max_debug_file_size"

    """DEPRECATED AND IGNORED"""
    RETAINED_HOST_ATTRIBUTE_MASK = "retained_host_attribute_mask"
    RETAINED_SERVICE_ATTRIBUTE_MASK = "retained_service_attribute_mask"
    RETAINED_PROCESS_HOST_ATTRIBUTE_MASK = "retained_process_host_attribute_mask"
    RETAINED_PROCESS_SERVICE_ATTRIBUTE_MASK = "retained_process_service_attribute_mask"
    FREE_CHILD_PROCESS_MEMORY = "free_child_process_memory"
    CHILD_PROCESSES_FORK_TWICE = "child_processes_fork_twice"




"""
This program is a library to communicate with the Centreon REST API

Copyright (C) 2019 Niklas Pfister, contact@omikron.pw

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""
import enum


class LDAP:
    """This class represents a LDAP configuraiton

    :param id_unique: ID of the configuraiton
    :type id_unique: int
    :param name: Name of the configuration
    :type name: str
    :param description: Description of the configuration
    :type description: str
    :param status: Status of the configuration
    :type status: bool
    """
    def __init__(self, id_unique, name, description, status):
        self.id_unique = id_unique
        self.name = name
        self.description = description
        self.status = status


class LDAPParam(enum.Enum):
    NAME = "name"
    DESCRIPTION = "description"
    ENABLED = "enable"
    ALIAS = "alias"
    BIND_DN = "bind_dn"
    BIND_PASS = "bind_pass"
    GROUP_BASE_SEARCH = "group_base_search"
    GROUP_FILTER = "group_filter"
    GROUP_MEMBER = "group_member"
    GROUP_NAME = "group_name"
    LDAP_AUTO_IMPORT = "ldap_auto_import"
    LDAP_CONTACT_TEMPLATE = "ldap_contact_tmpl"
    LDAP_DNS_USE_DOMAIN = "ldap_dns_use_domain"
    LDAP_SEARCH_LIMIT = "ldap_search_limit"
    LDAP_SEARCH_TIMEOUT = "ldap_search_timeout"
    LDAP_SRV_DNS = "ldap_srv_dns"
    LDAP_STORE_PASSWORD = "ldap_store_password"
    LDAP_TEMPLATE = "ldap_template"
    PROTOCOL_VERSION = "protocol_version"
    USER_BASE_SEARCH = "user_base_search"
    USER_EMAIL = "user_email"
    USER_FILTER = "user_filter"
    USER_FIRSTNAME = "user_firstname"
    USER_LASTNAME = "user_lastname"
    USER_NAME = "user_name"
    USER_PAGER = "user_pager"
    USER_GROUP = "user_group"


class LDAPServer:
    """This class represents a ldap server

    :param ip: IP of the server
    :type ip: str
    :param address: Address of the server
    :type address: str
    :param port: Port of the server
    :type port: int
    :param ssl: Is SSL enabled?
    :type ssl: bool
    :param tls: Is TLS enabled?
    :type tls: bool
    :param order: Order of the servers
    :type order: int
    """
    def __init__(self, id_unique, address, port, ssl, tls, order):
        self.id_unique = id_unique
        self.address = address
        self.port = port
        self.ssl = ssl
        self.tls = tls
        self.order = order


class LDAPServerParam(enum.Enum):
    """This class represents a parameter of a ldap server"""
    HOST_ADDRESS = "host_address"
    HOST_PORT = "host_port"
    HOST_ORDER = "host_order"
    USE_SSL = "use_ssl"
    USE_TLS = "use_tls"



"""
This program is a library to communicate with the Centreon REST API

Copyright (C) 2019 Niklas Pfister, contact@omikron.pw

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
"""
import enum


class TimePeriod:
    """This class represents a time period

    :param id_unique: ID of the time period
    :type id_unique: int
    :param name: Name of the time period
    :type name: str
    :param alias: Alias of the time period
    :type alias: str
    :param sunday: Period on sunday
    :type sunday: str
    :param monday: Period on monday
    :type monday: str
    :param tuesday: Period on tuesday
    :type tuesday: str
    :param wednesday: Period on wednesday
    :type wednesday: str
    :param thursday: Period on thursday
    :type thursday: str
    :param friday: Period on friday
    :type friday: str
    :param saturday: Period on saturday
    :type saturday: str
    """
    def __init__(self, id_unique, name, alias, sunday, monday, tuesday, wednesday, thursday, friday, saturday):
        self.id_unique = id_unique
        self.name = name
        self.alias = alias
        self.sunday = sunday
        self.monday = monday
        self.tuesday = tuesday
        self.wednesday = wednesday
        self.thursday = thursday
        self.friday = friday
        self.saturday = saturday


class TimePeriodParam(enum.Enum):
    """This class represents a parameter for a time period"""
    NAME = "name"
    ALIAS = "alias"
    SUNDAY = "sunday"
    MONDAY = "monday"
    TUESDAY = "tuesday"
    WEDNESDAY = "wednesday"
    THURSDAY = "thursday"
    FRIDAY = "friday"
    SATURDAY = "saturday"
    INCLUDE = "include"
    EXCLUDE = "exclude"


class TimePeriodException:
    """This class represents a exception

    :param days: Days to exclude
    :type days: str
    :param timerange: Timerange to exclude
    :type timerange: str
    """
    def __init__(self, days, timerange):
        self.days = days
        self.timerange = timerange
